==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/WebGridSortingStrategyDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridSortingStrategyDescription } from "./WebGridSortingStrategyDescription";
/**
 * @hidden
 */
export let WebGridSortingStrategyDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridSortingStrategyDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridSortingStrategyDescriptionMetadata.a == null) {
                WebGridSortingStrategyDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridSortingStrategyDescriptionMetadata.c(WebGridSortingStrategyDescriptionMetadata.a);
            }
            if (a.k(WebGridSortingStrategyDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebGridSortingStrategyDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridSortingStrategy");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
        }
        static d(a) {
            WebGridSortingStrategyDescriptionMetadata.b(a);
            a.ad("WebGridSortingStrategy", () => new WebGridSortingStrategyDescription());
            a.ac("WebGridSortingStrategy", WebGridSortingStrategyDescriptionMetadata.a);
        }
    }
    WebGridSortingStrategyDescriptionMetadata.$t = markType(WebGridSortingStrategyDescriptionMetadata, 'WebGridSortingStrategyDescriptionMetadata');
    WebGridSortingStrategyDescriptionMetadata.a = null;
    return WebGridSortingStrategyDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/WebGridSortingStrategyDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGridSortingStrategyDescription } from "./WebGridSortingStrategyDescription";
/**
 * @hidden
 */
export let WebGridSortingStrategyDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGridSortingStrategyDescriptionMetadata extends Base {
        static b(a) {
            if (WebGridSortingStrategyDescriptionMetadata.a == null) {
                WebGridSortingStrategyDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGridSortingStrategyDescriptionMetadata.c(WebGridSortingStrategyDescriptionMetadata.a);
            }
            if (a.k(WebGridSortingStrategyDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebGridSortingStrategyDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GridSortingStrategy");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
        }
        static d(a) {
            WebGridSortingStrategyDescriptionMetadata.b(a);
            a.ae("WebGridSortingStrategy", () => new WebGridSortingStrategyDescription());
            a.ad("WebGridSortingStrategy", WebGridSortingStrategyDescriptionMetadata.a);
        }
    }
    WebGridSortingStrategyDescriptionMetadata.$t = markType(WebGridSortingStrategyDescriptionMetadata, 'WebGridSortingStrategyDescriptionMetadata');
    WebGridSortingStrategyDescriptionMetadata.a = null;
    return WebGridSortingStrategyDescriptionMetadata;
})();
